<?php
namespace Ep\Form;

use Ep\Form\Element\Submit;
use Ep\Form\Helper\Form;
use Ep\Form\Helper\FormButton;
use Ep\Form\Helper\FormCheckbox;
use Ep\Form\Helper\FormControl;
use Ep\Form\Helper\FormElement;
use Ep\Form\Helper\FormElementErrors;
use Ep\Form\Helper\FormGroup;
use Ep\Form\Helper\FormInput;
use Ep\Form\Helper\FormLabel;
use Ep\Form\Helper\FormMultiCheckbox;
use Ep\Form\Helper\FormSelect;
use Indigo\Html\Helper\HtmlElement;
use Indigo\View\Helper\Indent;
use Indigo\View\Helper\RenderObject;
use Zend\Form\ConfigProvider as FormConfigProvider;
use Zend\Form\ElementFactory;
use Zend\ServiceManager\Factory\InvokableFactory;
use Zend\Stdlib\ArrayUtils;

/**
 * Class ConfigProvider
 *
 * @package Ep\Form
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class ConfigProvider extends FormConfigProvider
{
	public function __invoke()
	{
		return [
			'dependencies' => $this->getDependencyConfig(),
			'form_elements' => $this->getFormElementConfig(),
			'view_helpers' => $this->getViewHelperConfig(),
		];
	}

	/**
	 * @return array
	 */
	public function getDependencyConfig()
	{
		$config = parent::getDependencyConfig();
		$config['abstract_factories'] = [];

		return ArrayUtils::merge($config, [
			'abstract_factories' => [
				FormAbstractServiceFactory::class,
			],
		]);
	}

	/**
	 * @return array
	 */
	public function getFormElementConfig()
	{
		return [
			'aliases' => [
				'submit' => Submit::class,
				'Submit' => Submit::class,
			],
			'factories' => [
				Submit::class => ElementFactory::class,
			],
		];
	}

	/**
	 * @return array
	 */
	public function getViewHelperConfig()
	{
		return ArrayUtils::merge(parent::getViewHelperConfig(), [
			'aliases' => [
				'indent'       => Indent::class,
				'Indent'       => Indent::class,
				'renderobject' => RenderObject::class,
				'renderObject' => RenderObject::class,
				'RenderObject' => RenderObject::class,

				'htmlelement' => HtmlElement::class,
				'htmlElement' => HtmlElement::class,
				'HtmlElement' => HtmlElement::class,

				'form' => Form::class,
				'Form' => Form::class,
				'formbutton' => FormButton::class,
				'formButton' => FormButton::class,
				'FormButton' => FormButton::class,
				'formcheckbox' => FormCheckbox::class,
				'formCheckbox' => FormCheckbox::class,
				'FormCheckbox' => FormCheckbox::class,
				'formcontrol' => FormControl::class,
				'formControl' => FormControl::class,
				'FormControl' => FormControl::class,
				'formelement' => FormElement::class,
				'formElement' => FormElement::class,
				'FormElement' => FormElement::class,
				'formelementerrors' => FormElementErrors::class,
				'formElementErrors' => FormElementErrors::class,
				'FormElementErrors' => FormElementErrors::class,
				'formgroup' => FormGroup::class,
				'formGroup' => FormGroup::class,
				'FormGroup' => FormGroup::class,
				'forminput' => FormInput::class,
				'formInput' => FormInput::class,
				'FormInput' => FormInput::class,
				'formlabel' => FormLabel::class,
				'formLabel' => FormLabel::class,
				'FormLabel' => FormLabel::class,
				'formmulticheckbox' => FormMultiCheckbox::class,
				'formselect' => FormSelect::class,
				'formSelect' => FormSelect::class,
				'FormSelect' => FormSelect::class,
			],

			'factories' => [
				Indent::class       => InvokableFactory::class,
				RenderObject::class => InvokableFactory::class,

				HtmlElement::class => InvokableFactory::class,

				Form::class => InvokableFactory::class,
				FormButton::class => InvokableFactory::class,
				FormCheckbox::class => InvokableFactory::class,
				FormControl::class => InvokableFactory::class,
				FormElement::class => InvokableFactory::class,
				FormElementErrors::class => InvokableFactory::class,
				FormGroup::class => InvokableFactory::class,
				FormInput::class => InvokableFactory::class,
				FormLabel::class => InvokableFactory::class,
				FormMultiCheckbox::class => InvokableFactory::class,
				FormSelect::class => InvokableFactory::class,
			],
		]);
	}
}