<?php
namespace Ep\Form\Helper;

use Indigo\Html\Element as HtmlElement;
use Zend\Form\Element\Checkbox;
use Zend\Form\ElementInterface;

/**
 * Renderira <input type="checkbox"> element.
 *
 * @package Ep\Form\Helper
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class FormCheckbox extends AbstractFormHelper
{
	public function __invoke(ElementInterface $element = null)
	{
		if (null === $element) {
			return $this;
		}

		return $this->render($element);
	}

	/**
	 * Renderira element.
	 *
	 * @param ElementInterface $element Checkbox element.
	 *
	 * @return string
	 */
	public function render(ElementInterface $element)
	{
		if (!$element instanceof Checkbox) {
			throw new \InvalidArgumentException(
				sprintf('Element mora biti checkbox, a ne %s', get_class($element))
			);
		}

		$name = $element->getName();

		if (empty($name) && $name !== 0) {
			throw new \DomainException(sprintf(
				'%s requires that the element has an assigned name; none discovered',
				__METHOD__
			));
		}

		$attributes = $element->getAttributes();
		$attributes['name'] = $name;
		$attributes['type'] = $element->getAttribute('type');
		$attributes['value'] = $element->getCheckedValue();

		if ($element->isChecked()) {
			$attributes['checked'] = 'checked';
		}

		$input = new HtmlElement('input', $attributes);
		$input->addClass('form-check-input');

		$label = new HtmlElement('label', [
			'class' => 'form-check-label',
		]);

		if ($element->useHiddenElement()) {
			$hidden = new HtmlElement('input', [
				'type' => 'hidden',
				'name' => $input->getAttribute('name'),
				'disabled' => $input->getAttribute('disabled'),
				'value' => $element->getUncheckedValue(),
			]);
			$label->append($hidden);
		}

		$label->append($input);

		$labelText = new HtmlElement('span');
		$labelText->setContent($element->getOption('description'));

		$label->append($labelText);

		$wrapper = new HtmlElement('div', [
			'class' => 'form-check',
		]);
		$wrapper->append($label);

		return $this->getHtmlElementHelper()->render($wrapper);
	}
}