<?php
namespace Ep\Form\Helper;

use Indigo\Html\Element as HtmlElement;
use Indigo\Html\Helper\HtmlElement as HtmlElementHelper;
use Zend\Form\Element\MultiCheckbox;
use Zend\Form\ElementInterface;
use Zend\Form\LabelAwareInterface;
use Zend\Form\View\Helper\FormLabel as BaseFormLabel;

/**
 * Renderira label elementa forme.
 *
 * @package Ep\Form\Helper
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class FormLabel extends BaseFormLabel
{
	/** @var HtmlElementHelper */
	protected $htmlElement;

	/** @return HtmlElementHelper */
	protected function getHtmlElementHelper()
	{
		if (null === $this->htmlElement) {
			$this->htmlElement = method_exists($this->view, 'plugin')
				? $this->view->plugin('htmlElement')
				: new HtmlElementHelper();
		}
		return $this->htmlElement;
	}

	/**
	 * {@inheritdoc}
	 *
	 * @param ElementInterface $element Element čiji label renderiramo.
	 *
	 * @return string
	 */
	public function getId(ElementInterface $element)
	{
		$elementId = $element->getAttribute('id');

		if (null !== $elementId) {
			return $elementId;
		}

		$elementId = 'el-' . substr(md5($element->getName() . time()), 0, 6);
		$element->setAttribute('id', $elementId);
		return $elementId;
	}

	/**
	 * {@inheritdoc}
	 *
	 * @param null|array|ElementInterface $attributesOrElement Element ili atributi.
	 *
	 * @return string
	 */
	public function openTag($attributesOrElement = null)
	{
		if ($attributesOrElement instanceof ElementInterface
		    && $attributesOrElement instanceof LabelAwareInterface
		) {
			$label = new HtmlElement('label', $attributesOrElement->getLabelAttributes());

			$label->addClass('form-control-label');

			if (!$attributesOrElement instanceof MultiCheckbox) {
				$label->setAttribute('for', $this->getId($attributesOrElement));
			}

			if ($attributesOrElement->getAttribute('required')) {
				$label->addClass('required');
			}

			$attributes = [];
			foreach ($label->getAttributes() as $attribute) {
				$attributes[$attribute->getName()] = $attribute->getValue();
			}

			$attributesOrElement->setLabelAttributes((array) $attributes);
			$htmlElement = $this->getHtmlElementHelper();

			return $htmlElement->openTag($label);
		}

		return parent::openTag($attributesOrElement);
	}
}