<?php
namespace Ep\Gath\Adapter;

/**
 * Dohvaća podatke direktno iz remote Gatha.
 *
 * @package Ep\Gath\Adapter
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
interface AdapterInterface
{
	/**
	 * Vraća cijene za date proizvode.
	 *
	 * @param array $skus
	 * @param bool $retail
	 * @param bool $wholesale
	 * @param bool $discounts
	 * @param string|null $username
	 *
	 * @return mixed
	 */
	public function getPrices(array $skus, bool $retail, bool $wholesale = true, bool $discounts = true, string $username = null);

    /**
     * Vraća proizvode iz date kategorije.
     *
     * @param int $categoryId
     * @param int $order
     * @param int $limit
     * @param int $offset
     *
     * @return mixed
     */
	public function getProductsByCategory(int $categoryId, int $order, int $limit = 10, int $offset = 0);

	/**
	 * Vraća proizvode po id-u.
	 *
	 * @param array $productIds
	 *
	 * @return mixed
	 */
	public function getProductsByIds(array $productIds);

	/**
	 * Vraća stanje zalihe za date proizvode.
	 *
	 * @param array $skus
	 * @param string|null $username
	 *
	 * @return mixed
	 */
	public function getStock(array $skus, string $username = null);

    /**
     * @param array $tecDocPairs
     * @param int $order
     * @param int $limit
     * @param int $offset
     *
     * @return mixed
     */
	public function getTecDocProducts(array $tecDocPairs, int $order, int $limit = 10, int $offset = 0);
}