<?php
namespace Ep\Gath\Adapter;

use Ep\Cache\Service\CacheManager;
use Ep\Http\Service\HttpClientManager;
use GuzzleHttp\Client as HttpClient;
use Interop\Container\ContainerInterface;
use Interop\Container\Exception\ContainerException;
use Zend\ServiceManager\Exception\ServiceNotCreatedException;
use Zend\ServiceManager\Exception\ServiceNotFoundException;
use Zend\ServiceManager\Factory\FactoryInterface;

/**
 * Stvara novu instancu REST adaptera za Gath.
 *
 * @package Ep\Gath\Adapter
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class RestAdapterFactory implements FactoryInterface
{
	/**
	 * Stvara objekt
	 *
	 * @param  ContainerInterface $container
	 * @param  string $requestedName
	 * @param  null|array $options
	 *
	 * @return object
	 * @throws ServiceNotFoundException if unable to resolve the service.
	 * @throws ServiceNotCreatedException if an exception is raised when
	 *     creating a service.
	 * @throws ContainerException if any other error occurs
	 */
	public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
	{
		/** @var HttpClientManager $httpClientManager */
		$httpClientManager = $container->get('HttpClientManager');
		$client = $httpClientManager->get('gath');

		/** @var CacheManager $cacheManager */
		$cacheManager = $container->get('CacheManager');
		$cache = $cacheManager->get('gath');

		$log = $container->get('Log');

		return new RestAdapter($client, $cache, $log);
	}
}