<?php
namespace Ep\Gath\Entity;

use DateTime;

/**
 * Class Product
 *
 * @package Ep\Gath\Entity
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class Product
{
	/** @var int */
	protected $id;
	/** @var string */
	protected $sku;
	/** @var string */
	protected $name;
	/** @var string */
	protected $description;
	/** @var string */
	protected $shortDescription;
	/** @var DateTime */
	protected $dateModified;
	/** @var string */
	protected $fallbackTaxClass;
	/** @var string */
	protected $taxClass;
	/** @var bool */
	protected $featured;
	/** @var int */
	protected $tecdocBrandNo;
	/** @var string */
	protected $tecdocArticleNo;
	/** @var ProductBrand[] */
	protected $brands;
	/** @var ProductShippingClass[] */
	protected $shippingClasses;
	/** @var ProductImage[] */
	protected $images;

	/**
	 * @return int
	 */
	public function getId(): int
	{
		return $this->id;
	}

	/**
	 * @return string
	 */
	public function getSku(): string
	{
		return $this->sku;
	}

	/**
	 * @return string
	 */
	public function getName(): string
	{
		return $this->name;
	}

	/**
	 * @return string
	 */
	public function getDescription(): string
	{
//		return (string) $this->description;
		return '';
	}

	/**
	 * @return string
	 */
	public function getShortDescription(): string
	{
		return (string) $this->shortDescription;
	}

	/**
	 * @return DateTime
	 */
	public function getDateModified(): ?DateTime
	{
		return $this->dateModified;
	}

	/**
	 * @return string
	 */
	public function getTaxClass(): string
	{
		return empty($this->taxClass)
			? $this->fallbackTaxClass
			: $this->taxClass;
	}

	/**
	 * @return bool
	 */
	public function isFeatured(): bool
	{
		return (bool) $this->featured;
	}

	/**
	 * @return int
	 */
	public function getTecdocBrandNo(): int
	{
		return (int) $this->tecdocBrandNo;
	}

	/**
	 * @return string
	 */
	public function getTecdocArticleNo(): string
	{
		return (string) $this->tecdocArticleNo;
	}

	/**
	 * @return bool
	 */
	public function hasBrand()
	{
		return is_array($this->brands) && count($this->brands) > 0;
	}

	/**
	 * @return ProductBrand|null
	 */
	public function getBrand(): ?ProductBrand
	{
		return $this->hasBrand() ? $this->brands[0] : null;
	}

	/**
	 * @return int
	 */
	public function getBrandId(): int
	{
		return $this->hasBrand() ? $this->getBrand()->getId() : 0;
	}

	/**
	 * @return bool
	 */
	public function hasShippingClass(): bool
	{
		return is_array($this->shippingClasses) && count($this->shippingClasses) > 0;
	}

	/**
	 * @return ProductShippingClass|null
	 */
	public function getShippingClass(): ?ProductShippingClass
	{
		return $this->hasShippingClass() ? $this->shippingClasses[0] : null;
	}

	/**
	 * @return int
	 */
	public function getShippingClassId(): int
	{
		return $this->hasShippingClass() ? $this->getShippingClass()->getId() : 0;
	}

	/**
	 * @return bool
	 */
	public function hasImages(): bool
	{
		return is_array($this->images) && count($this->images) > 0;
	}

	/**
	 * @return ProductImage[]
	 */
	public function getImages(): array
	{
		return $this->hasImages() ? $this->images : [];
	}

	/**
	 * @return bool
	 */
	public function hasThumbnail(): bool
	{
		return $this->hasImages();
	}

	/**
	 * @return ProductImage
	 */
	public function getThumbnail(): ProductImage
	{
		return $this->hasThumbnail()
			? $this->images[0]
			: null;
	}
}
