<?php
namespace Ep\Gath\WordPress;

use Ep\WordPress\Service\AbstractWordPressService;

/**
 * Class ImageProvider
 *
 * @package Ep\Gath\WordPress
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class ImageProvider extends AbstractWordPressService
{
	public function attach(): void
	{
		add_filter('wp_get_attachment_image_src', [$this, 'getImageSrc'], 10, 3);
	}

	/**
	 * @param $image
	 * @param $attachmentId
	 * @param $size
	 *
	 * @return mixed
	 */
	public function getImageSrc($image, $attachmentId, $size)
	{
		if (preg_match('/^([a-z]+)-(.+)/', $attachmentId, $matches)) {
			if ('gath' === $matches[1]) {
				$imageUrl = $this->getImageUrl($matches[2], $size);
			} else {
				$imageUrl = $matches[2];
			}

			return [$imageUrl, null, null];
		} else if (!is_numeric($attachmentId)) {
			return [$attachmentId, null, null];
		}

		return $image;
	}

	/**
	 * @param $path
	 * @param string $size
	 * @param bool $cropped
	 *
	 * @return string
	 */
	public function getImageUrl($path, $size = 'full', $cropped = false)
	{
		$config = $this->getConfig('gath');
		$baseUri = rtrim(preg_replace('/^https?:/', '', $config['images_base_uri']), '/');

		if (empty($baseUri)) {
			throw new \RuntimeException('Nije zadan osnovni URI servisa sa slikama.');
		}

		$parts = [];

		if ($size !== 'full') {
			if (is_string($size)) {
				global $_wp_additional_image_sizes;

				if (!isset($_wp_additional_image_sizes[$size]) && !in_array($size, ['thumbnail', 'medium', 'medium_large', 'large'])) {
					throw new \RuntimeException(sprintf("Nepoznata veličina slike '%s'.", $size));
				}

				if (in_array($size, ['thumbnail', 'medium', 'medium_large', 'large'])) {
					$width = get_option("{$size}_size_w");
					$height = get_option("{$size}_size_h");
					$cropped = (bool) get_option("{$size}_crop");
				} else {
					$width = $_wp_additional_image_sizes[$size]['width'];
					$height = $_wp_additional_image_sizes[$size]['height'];
					$cropped = $_wp_additional_image_sizes[$size]['crop'];
				}
			} else if (is_array($size)) {
				[$width, $height] = $size;
			} else {
				throw new \RuntimeException(sprintf(
					"Neispravan parametar \$size, mora biti string ili array a dobio sam %s.",
					is_object($size) ? get_class($size) : gettype($size)
				));
			}

			$parts[] = sprintf('%sx%s', $width, $height);
		}

		if ($cropped) {
			array_unshift($parts, 'cropped');
		}

		$parts[] = $path;

		return sprintf('%s/images/%s', $baseUri, implode('/', $parts));
	}
}