<?php
namespace Ep\Gath\WordPress;

use Ep\WordPress\Service\MetadataProviderInterface;
use WP_Post;

/**
 * Class OrderProvider
 *
 * Mislim da nam ovo neće trebat.
 *
 * @package Ep\Gath\WordPress
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class OrderTypeProvider implements MetadataProviderInterface
{
	/**
	 * Omogućava providerima da preloadaju metapodatke za set postova.
	 *
	 * @param WP_Post[]|int[] $posts
	 *
	 * @return void
	 */
	public function preloadMetadata(array $posts): void
	{
		// Ne preloadamo ništa za narudžbe
	}

	/**
	 * Vraća true ako ovaj provider može vratiti metapodatak s datim ključem.
	 *
	 * @param string $metaKey
	 *
	 * @return bool
	 */
	public function hasMetadata(string $metaKey): bool
	{
		return '_order_type' === $metaKey;
	}

	/**
	 * Vraća vrijednost metapodatka iz nekog drugog izvora, ovisno o implementaciji.
	 *
	 * @param int $postId
	 * @param string $metaKey
	 * @param mixed|null $metaValue
	 *
	 * @return mixed
	 */
	public function getMetadata(int $postId, string $metaKey, $metaValue = null)
	{
		if ('_order_type' === $metaKey) {
			$config = get_option('ep_webshop', []);
			return $config['type'] ?? 'retail';
		}

		return '';
	}
}