<?php
namespace Ep\View;

use Twig_Environment;
use Zend\View\HelperPluginManager;
use Zend\View\Model\ModelInterface;
use Zend\View\Renderer\RendererInterface;
use Zend\View\Resolver\ResolverInterface;

/**
 * Wrapper za Twig.
 *
 * @package Ep\View
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class ViewRenderer implements RendererInterface
{
	/** @var Twig_Environment */
	protected $twig;
	/** @var HelperPluginManager */
	protected $helpers;

	/**
	 * ViewRenderer constructor.
	 *
	 * @param Twig_Environment $twig
	 * @param HelperPluginManager $helpers
	 */
	public function __construct(Twig_Environment $twig, HelperPluginManager $helpers)
	{
		$this->twig = $twig;
		$this->helpers = $helpers;

		$helpers->setRenderer($this);
	}

	/**
	 * Poziva helper direktno.
	 *
	 * @param $name
	 * @param $arguments
	 *
	 * @return mixed
	 */
	public function __call($name, $arguments)
	{
		$helper = $this->plugin($name);
		return call_user_func_array($helper, $arguments);
	}

	/**
	 * Return the template engine object, if any
	 *
	 * If using a third-party template engine, such as Smarty, patTemplate,
	 * phplib, etc, return the template engine object. Useful for calling
	 * methods on these objects, such as for setting filters, modifiers, etc.
	 *
	 * @return mixed
	 */
	public function getEngine()
	{
		return $this->twig;
	}

	/**
	 * Set the resolver used to map a template name to a resource the renderer may consume.
	 *
	 * @param  ResolverInterface $resolver
	 *
	 * @return RendererInterface
	 */
	public function setResolver(ResolverInterface $resolver)
	{
		return $this;
	}

	/**
	 * Processes a view script and returns the output.
	 *
	 * @param  string|ModelInterface $nameOrModel The script/resource process, or a view model
	 * @param  null|array|\ArrayAccess $values Values to use during rendering
	 *
	 * @return string The script output.
	 */
	public function render($nameOrModel, $values = null)
	{
		return $this->twig->render($nameOrModel, $values);
	}

	/**
	 * Vraća ViewHelper registriran pod datim imenom.
	 *
	 * @param $name
	 *
	 * @return callable
	 */
	public function plugin($name)
	{
		return $this->helpers->get($name);
	}
}