<?php
namespace Ep\View;

use Interop\Container\ContainerInterface;
use Interop\Container\Exception\ContainerException;
use Twig_Environment;
use Zend\ServiceManager\Exception\ServiceNotCreatedException;
use Zend\ServiceManager\Exception\ServiceNotFoundException;
use Zend\ServiceManager\Factory\FactoryInterface;
use Zend\View\HelperPluginManager;

/**
 * Class ViewRendererFactory
 *
 * @package Ep\View
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class ViewRendererFactory implements FactoryInterface
{
	/**
	 * Create an object
	 *
	 * @param  ContainerInterface $container
	 * @param  string $requestedName
	 * @param  null|array $options
	 *
	 * @return object
	 * @throws ServiceNotFoundException if unable to resolve the service.
	 * @throws ServiceNotCreatedException if an exception is raised when
	 *     creating a service.
	 * @throws ContainerException if any other error occurs
	 */
	public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
	{
		/** @var Twig_Environment $twig */
		$twig = $container->get('Twig');
		/** @var HelperPluginManager $helperPluginManager */
		$helperPluginManager = $container->get('ViewHelperManager');

		return new ViewRenderer($twig, $helperPluginManager);
	}
}