<?php
namespace Ep\WooCommerce;

use Ep\WordPress\Service\AbstractWordPressService;
use WC_Coupon;

/**
 * Class CouponService
 *
 * @package Ep\WooCommerce
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class CouponService extends AbstractWordPressService
{
	public function attach(): void
	{
		add_action('save_post', [$this, 'savePost'], 10, 3);
		add_filter('woocommerce_coupon_is_valid', [$this, 'couponIsValid'], 10, 2);
		add_action('woocommerce_coupon_options_usage_restriction', [$this, 'couponUsageRestriction'], 10, 2);
	}

	/**
	 * @param $valid
	 * @param WC_Coupon $coupon
	 *
	 * @return bool
	 */
	public function couponIsValid($valid, WC_Coupon $coupon)
	{
		$users_registered_before = get_post_meta($coupon->get_id(), '_users_registered_before', true);

		if (!empty($users_registered_before)) {
			if (0 === get_current_user_id()) return false;

			$user = wp_get_current_user();
			$before = strtotime($users_registered_before);
			$userRegistered = strtotime($user->user_registered);

			$valid = $before > $userRegistered;
		}

		return $valid;
	}

	/**
	 * @param $couponId
	 * @param WC_Coupon $coupon
	 */
	public function couponUsageRestriction($couponId, WC_Coupon $coupon)
	{
		$users_registered_before = get_post_meta($couponId, '_users_registered_before', true);

		woocommerce_wp_text_input([
			'id'                => 'users_registered_before',
			'value'             => esc_attr($users_registered_before),
			'label'             => 'Dozvoli korisnicima registriranim prije',
			'placeholder'       => 'YYYY-MM-DD',
			'description'       => '',
			'class'             => 'date-picker',
			'custom_attributes' => [
				'pattern' => apply_filters('woocommerce_date_input_html_pattern', '[0-9]{4}-(0[1-9]|1[012])-(0[1-9]|1[0-9]|2[0-9]|3[01])'),
			],
		]);
	}

	/**
	 * @param $couponId
	 * @param $coupon
	 * @param $update
	 */
	public function savePost($couponId, $coupon, $update)
	{
		$postType = get_post_type($couponId);
		if ('shop_coupon' !== $postType) return;

		if (isset($_POST['users_registered_before'])) {
			update_post_meta($couponId, '_users_registered_before', $_POST['users_registered_before']);
		}
	}
}