<?php
namespace Ep\WooCommerce;

use Ep\WooCommerce\Product\SimpleProduct;
use Ep\WordPress\Service\AbstractWordPressService;

/**
 * Class ProductService
 *
 * @package Ep\WooCommerce
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class ProductService extends AbstractWordPressService
{
	/**
	 * Kačimo se na WordPress.
	 */
	public function attach(): void
	{
		add_filter('woocommerce_product_class', [$this, 'getProductClass'], 10, 2);

		add_filter('woocommerce_product_get_price', [$this, 'getProductPrice'], 10, 1);
		add_filter('woocommerce_variation_prices_price', [$this, 'getProductPrice'], 10, 1);
		add_filter('woocommerce_variation_prices_regular_price', [$this, 'getProductPrice'], 10, 1);
		add_filter('woocommerce_variation_prices_sale_price', [$this, 'getProductPrice'], 10, 1);

		add_filter('woocommerce_empty_price_html', [$this, 'getEmptyPriceHtml'], 10, 1);
		add_filter('woocommerce_grouped_empty_price_html', [$this, 'getEmptyPriceHtml'], 10, 1);
		add_filter('woocommerce_variable_empty_price_html', [$this, 'getEmptyPriceHtml'], 10, 1);

        add_filter('woocommerce_catalog_orderby', [$this, 'catalogOrderBy']);
	}

	public function catalogOrderBy($options)
    {
        return [
            'date' => $options['date'],
            'price' => $options['price'],
            'price-desc' => $options['price-desc'],
        ];
    }

	/**
	 * Vraća ime klase za datu vrstu proizvoda.
	 *
	 * @param string $className
	 * @param string $productType
	 *
	 * @return string
	 */
	public function getProductClass(string $className, string $productType): string
	{
		switch($productType) {
			case 'simple':
				return SimpleProduct::class;
			default:
				return $className;
		}
	}

	/**
	 * Vraća cijenu proizvoda.
	 *
	 * @param $price
	 *
	 * @return string
	 */
	public function getProductPrice($price)
	{
		$config = $this->getConfig('webshop');

		if ('1' === $config['login_for_prices'] && wp_get_current_user()->ID === 0) {
			return '';
		}

		return $price;
	}

	/**
	 * Vraća link za login umjesto cijene.
	 *
	 * @param $html
	 *
	 * @return mixed
	 */
	public function getEmptyPriceHtml($html)
	{
		$config = $this->getConfig('webshop');

		if ('1' === $config['login_for_prices'] && wp_get_current_user()->ID === 0) {
			return sprintf(
				'<a href="%s">%s</a>',
				get_permalink(get_option('woocommerce_myaccount_page_id')),
				$config['login_for_prices_text'] ?: 'Login za cijene'
			);
		}

		return $html;
	}
}