<?php
namespace Ep\WordPress\Service;

use Ep\Core\UserProviderInterface;

/**
 * WordPress korisnici.
 *
 * @package Ep\WordPress
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class UserService extends AbstractWordPressService implements UserProviderInterface
{
	/**
	 * Pokreće se prilikom aktivacije plugina.
	 *
	 * Dodaje rolu za veleprodajnog kupca.
	 */
	public function activate(): void
	{
		$role = get_role('wholesale_customer');

		if (null === $role) {
			add_role('wholesale_customer', 'Veleprodajni kupac');
		}
	}

	/**
	 * Vraća true ako imamo ulogiranog korisnika.
	 *
	 * @return bool
	 */
	public function hasUser(): bool
	{
		return get_current_user_id() > 0;
	}

	/**
	 * Vraća korisničko ime trenutno ulogiranog korisnika.
	 *
	 * @return string|null
	 */
	public function getUsername(): string
	{
		return $this->hasUser()
			? wp_get_current_user()->user_login
			: null;
	}

	/**
	 * Vraća true ako je ulogirani korisnik veleprodajni kupac.
	 *
	 * @return bool
	 */
	public function isWholesale(): bool
	{
		return $this->hasUser()
			? in_array('wholesale_customer', (array) wp_get_current_user()->roles)
			: false;
	}
}