<?php
namespace Ep\WordPress\Settings;

use Interop\Container\ContainerInterface;
use Interop\Container\Exception\ContainerException;
use Zend\ConfigAggregator\ConfigAggregator;
use Zend\ServiceManager\Exception\ServiceNotCreatedException;
use Zend\ServiceManager\Exception\ServiceNotFoundException;
use Zend\ServiceManager\Factory\FactoryInterface;

/**
 * Class SettingsServiceFactory
 *
 * @package Ep\WordPress\Settings
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class SettingsServiceFactory implements FactoryInterface
{
	/**
	 * Create an object
	 *
	 * @param  ContainerInterface $container
	 * @param  string $requestedName
	 * @param  null|array $options
	 *
	 * @return object
	 * @throws ServiceNotFoundException if unable to resolve the service.
	 * @throws ServiceNotCreatedException if an exception is raised when
	 *     creating a service.
	 * @throws ContainerException if any other error occurs
	 */
	public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
	{
		$providers = $container->get('configProviders');
		$settings = new SettingsService($container);

		foreach ($providers as $provider) {
			if (is_string($provider) && class_exists($provider)) {
				$provider = new $provider();

				if ($provider instanceof SettingsProviderInterface) {
					$settings->addProvider($provider);
				}
			}
		}

		return $settings;
	}
}