<?php
namespace EpTest;

use Ep\Core\ServiceManagerFactory;
use Ep\Test\WordPressTestCase;
use EpTest\Gath\Adapter\RestAdapterMock;
use PHPUnit\Framework\TestCase;
use Psr\Container\ContainerInterface;
use Zend\Form\Form;
use Zend\Hydrator\HydratorInterface;
use Zend\InputFilter\InputFilterPluginManager;
use Zend\ServiceManager\Factory\InvokableFactory;
use Zend\ServiceManager\PluginManagerInterface;
use Zend\Validator\ValidatorPluginManager;

/**
 * Osnovna klasa za testove integracije.
 *
 * @package EpTest
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
abstract class IntegrationTestCase extends WordPressTestCase
{
	/** @var ContainerInterface */
	private $services;

	protected $wpOptions = [
		'siteurl' => 'http://test.localhost',
	];

	/**
	 * IntegrationTestCase constructor.
	 *
	 * @param null $name
	 * @param array $data
	 * @param string $dataName
	 */
	public function __construct($name = null, array $data = [], $dataName = '')
	{
		parent::__construct($name, $data, $dataName);
	}

	public function setUp()
	{
		wp_register_plugin_realpath(__DIR__ . '/../plugin.php');
		require_once __DIR__ . '/../plugin.php';

		parent::setUp();
	}

	/**
	 * @param string $name
	 *
	 * @return Form
	 */
	protected function getForm(string $name)
	{
		$services = $this->getServiceManager();
		return $services->get($name);
	}

	/**
	 * Vraća HydratorManager.
	 *
	 * @return PluginManagerInterface
	 */
	protected function getHydratorManager()
	{
		$services = $this->getServiceManager();
		return $services->get('HydratorManager');
	}

	/**
	 * Vraća hidrator po imenu.
	 *
	 * @param string $name Ime hidratora.
	 *
	 * @return HydratorInterface
	 */
	protected function getHydrator(string $name)
	{
		$services = $this->getServiceManager();
		/** @var PluginManagerInterface $hydrators */
		$hydrators = $services->get('HydratorManager');
		return $hydrators->get($name);
	}

	/**
	 * @return InputFilterPluginManager
	 */
	protected function getInputFilterManager()
	{
		$services = $this->getServiceManager();
		return $services->get('InputFilterManager');
	}

	/**
	 * Vraća konfiguriran ServiceManager.
	 *
	 * @return ContainerInterface
	 */
	protected function getServiceManager()
	{
		if (null === $this->services) {
			$factory = new ServiceManagerFactory();
			$this->services = $factory();
		}
		return $this->services;
	}

	/**
	 * @return ValidatorPluginManager
	 */
	protected function getValidatorManager()
	{
		$services = $this->getServiceManager();
		return $services->get('ValidatorManager');
	}
}